import { registerExtension } from '@codingame/monaco-vscode-api/extensions';

const manifest = {"name":"ocaml-platform","displayName":"OCaml Platform","version":"1.28.0","private":true,"description":"Official OCaml language extension for VSCode","categories":["Programming Languages","Debuggers"],"homepage":"https://github.com/ocamllabs/vscode-ocaml-platform","bugs":{"url":"https://github.com/ocamllabs/vscode-ocaml-platform/issues"},"repository":{"type":"git","url":"git+https://github.com/ocamllabs/vscode-ocaml-platform.git"},"license":"MIT","publisher":"ocamllabs","sideEffects":false,"type":"commonjs","files":["assets","astexplorer/dist","dist","languages","LICENSE","snippets","syntaxes"],"workspaces":["astexplorer"],"contributes":{"configuration":{"title":"OCaml Platform","properties":{"ocaml.sandbox":{"type":"object","default":null,"description":"Determines where to find the sandbox for a given project"},"ocaml.server.extraEnv":{"type":["null","object"],"default":null,"markdownDescription":"Extra environment variables that will be passed to OCaml LSP executable. Useful for debugging purposes mostly."},"ocaml.server.args":{"type":"array","items":"string","default":[],"markdownDescription":"Extra arguments to pass to ocamllsp."},"ocaml.server.codelens":{"type":"boolean","default":true,"markdownDescription":"Enable/Disable codelens"},"ocaml.server.extendedHover":{"type":"boolean","default":false,"markdownDescription":"Enable/Disable extended hover"},"ocaml.server.duneDiagnostics":{"type":"boolean","default":true,"markdownDescription":"Enable/Disable dune diagnostics"},"ocaml.commands.typeSelection.outputChannelResults":{"type":"boolean","default":true,"markdownDescription":"Enable/Disable type of selection results to appear in a dedicated output channel in the side panel."},"ocaml.commands.typeSelection.alwaysClearOutputChannel":{"type":"boolean","default":false,"markdownDescription":"Enable/Disable clearing of the output channel before showing a new result."},"ocaml.server.syntaxDocumentation":{"type":"boolean","default":false,"markdownDescription":"Enable/Disable syntax documentation"},"ocaml.commands.typedHoles.constructAfterNavigate":{"type":"boolean","default":false,"markdownDescription":"When enabled, list values that can fill a typed hole after navigating to it."},"ocaml.commands.construct.recursiveCalls":{"type":"boolean","default":true,"markdownDescription":"When enabled, the construct command will execute again on the next hole after a value has been chosen."},"ocaml.dune.autoDetect":{"type":"boolean","default":true,"description":"Controls whether dune tasks should be automatically detected."},"ocaml.trace.server":{"description":"Controls the logging output of the language server. Valid settings are `off`, `messages`, or `verbose`.","type":"string","enum":["off","messages","verbose"],"default":"off"},"ocaml.useOcamlEnv":{"type":"boolean","default":true,"description":"Controls whether to use ocaml-env (if available) for opam commands from OCaml for Windows."},"ocaml.terminal.shell.linux":{"description":"The path of the shell that the sandbox terminal uses on Linux","type":["string","null"],"default":null},"ocaml.terminal.shell.osx":{"description":"The path of the shell that the sandbox terminal uses on macOS","type":["string","null"],"default":null},"ocaml.terminal.shell.windows":{"description":"The path of the shell that the sandbox terminal uses on Windows","type":["string","null"],"default":null},"ocaml.terminal.shellArgs.linux":{"description":"The command line arguments that the sandbox terminal uses on Linux","type":["array","null"],"items":"string","default":null},"ocaml.terminal.shellArgs.osx":{"description":"The command line arguments that the sandbox terminal uses on macOS","type":["array","null"],"items":"string","default":null},"ocaml.terminal.shellArgs.windows":{"description":"The command line arguments that the sandbox terminal uses on Window","type":["array","null"],"items":"string","default":null},"ocaml.repl.path":{"description":"The path of the REPL that the extension uses","type":["string","null"],"default":null},"ocaml.repl.args":{"description":"The REPL arguments that the extension uses","type":["array","null"],"items":"string","default":null},"ocaml.repl.useUtop":{"type":"boolean","default":true,"description":"Controls whether to use Utop for the REPL if it is installed in the current switch."}}},"configurationDefaults":{"[ocaml]":{"editor.tabSize":2,"editor.insertSpaces":true},"[dune]":{"editor.tabSize":1,"editor.insertSpaces":true},"[dune-project]":{"editor.tabSize":1,"editor.insertSpaces":true},"[dune-workspace]":{"editor.tabSize":1,"editor.insertSpaces":true},"[cram]":{"editor.tabSize":2,"editor.insertSpaces":true},"[reason]":{"editor.semanticHighlighting.enabled":false}},"customEditors":[{"viewType":"ast-editor","displayName":"OCaml AST preview","priority":"option","selector":[{"filenamePattern":"*.ml"},{"filenamePattern":"*.mli"}]},{"viewType":"cm-files-editor","displayName":"OCaml Compilation Artifact Viewer","selector":[{"filenamePattern":"*.cmi"},{"filenamePattern":"*.cmt"},{"filenamePattern":"*.cmti"},{"filenamePattern":"*.cmo"},{"filenamePattern":"*.cma"},{"filenamePattern":"*.cmx"},{"filenamePattern":"*.cmxa"},{"filenamePattern":"*.cmxs"},{"filenamePattern":"*.bc"}]}],"grammars":[{"language":"dune","scopeName":"source.dune","path":"./syntaxes/dune.json"},{"language":"dune-project","scopeName":"source.dune-project","path":"./syntaxes/dune-project.json"},{"language":"dune-workspace","scopeName":"source.dune-workspace","path":"./syntaxes/dune-workspace.json"},{"language":"ocaml.merlin","scopeName":"source.ocaml.merlin","path":"./syntaxes/merlin.json"},{"scopeName":"markdown.ocaml.codeblock","path":"./syntaxes/ocaml-markdown-codeblock.json","injectTo":["text.html.markdown"],"embeddedLanguages":{"meta.embedded.block.ocaml":"ocaml"}},{"language":"ocaml","scopeName":"source.ocaml","path":"./syntaxes/ocaml.json"},{"language":"ocaml.interface","scopeName":"source.ocaml.interface","path":"./syntaxes/ocaml.interface.json"},{"language":"ocaml.ocamlbuild","scopeName":"source.ocaml.ocamlbuild","path":"./syntaxes/ocamlbuild.json"},{"language":"ocaml.ocamldoc","scopeName":"source.ocaml.ocamldoc","path":"./syntaxes/ocamldoc.json"},{"language":"ocaml.ocamlformat","scopeName":"source.ocaml.ocamlformat","path":"./syntaxes/ocamlformat.json"},{"language":"ocaml.ocamllex","scopeName":"source.ocaml.ocamllex","path":"./syntaxes/ocamllex.json"},{"scopeName":"source.action.menhir","path":"./syntaxes/menhir-action.json","injectTo":["source.ocaml"]},{"language":"ocaml.menhir","scopeName":"source.ocaml.menhir","path":"./syntaxes/menhir.json","embeddedLanguages":{"source.embedded-action.menhir":"source.action.menhir"}},{"language":"ocaml.opam","scopeName":"source.ocaml.opam","path":"./syntaxes/opam.json"},{"language":"ocaml.opam-install","scopeName":"source.ocaml.opam-install","path":"./syntaxes/opam-install.json"},{"language":"ocaml.META","scopeName":"source.ocaml.META","path":"./syntaxes/META.json"},{"language":"ocaml.oasis","scopeName":"source.ocaml.oasis","path":"./syntaxes/oasis.json"},{"language":"atd","scopeName":"source.atd","path":"./syntaxes/atd.json"},{"scopeName":"markdown.reason.codeblock","path":"./syntaxes/reason-markdown-codeblock.json","injectTo":["text.html.markdown"],"embeddedLanguages":{"meta.embedded.block.reason":"reason"}},{"language":"reason","scopeName":"source.reason","path":"./syntaxes/reason.json"},{"language":"cram","scopeName":"source.cram","path":"./syntaxes/cram.json"}],"jsonValidation":[{"fileMatch":"esy.json","url":"https://raw.githubusercontent.com/esy/esy-schema/master/esySchema.json"}],"languages":[{"id":"dune","aliases":["dune"],"extensions":["dune","jbuild"],"configuration":"./languages/dune.json"},{"id":"dune-project","aliases":["dune project"],"extensions":["dune-project"],"configuration":"./languages/dune.json"},{"id":"dune-workspace","aliases":["dune workspace"],"filenames":["dune-workspace"],"filenamePatterns":["dune-workspace.*"],"configuration":"./languages/dune.json"},{"id":"ocaml.merlin","aliases":["Merlin","merlin"],"extensions":[".merlin"]},{"id":"ocaml","aliases":["OCaml","ocaml"],"extensions":[".ml",".eliom",".ocamlinit"],"configuration":"./languages/ocaml.json"},{"id":"ocaml.interface","aliases":["OCaml Interface","ocaml interface"],"extensions":[".mli",".eliomi"],"configuration":"./languages/ocaml.json"},{"id":"ocaml.opam","aliases":["opam"],"filenames":["opam"],"extensions":[".opam",".opam.locked",".opam.template"],"configuration":"./languages/opam.json"},{"id":"ocaml.opam-install","aliases":["opam install"],"extensions":[".install"],"configuration":"./languages/opam-install.json"},{"id":"ocaml.META","aliases":["META","meta"],"filenames":["META"],"configuration":"./languages/META.json"},{"id":"ocaml.ocamlbuild","aliases":["OCamlbuild","ocamlbuild"],"extensions":["_tags"],"configuration":"./languages/ocamlbuild.json"},{"id":"ocaml.oasis","aliases":["OASIS","oasis"],"extensions":["_oasis"],"configuration":"./languages/oasis.json"},{"id":"ocaml.ocamldoc","aliases":["OCamldoc","ocamldoc"],"extensions":[".mld"]},{"id":"ocaml.ocamlformat","aliases":["OCamlFormat","ocamlformat"],"extensions":[".ocamlformat"],"configuration":"./languages/ocamlformat.json"},{"id":"ocaml.ocamllex","aliases":["OCamllex","ocamllex"],"extensions":[".mll"],"configuration":"./languages/ocamllex.json"},{"id":"ocaml.menhir","aliases":["Menhir","menhir","OCamlyacc","ocamlyacc"],"extensions":[".mly"],"configuration":"./languages/menhir.json"},{"id":"atd","aliases":["ATD","atd"],"extensions":[".atd"],"configuration":"./languages/ocaml.json"},{"id":"reason","aliases":["Reason","reason"],"extensions":[".re",".rei"],"configuration":"./languages/reason.json"},{"id":"cram","aliases":["Cram Test","Cram","cram"],"extensions":[".t"]}],"problemMatchers":[{"name":"ocamlc","fileLocation":["relative","${workspaceFolder}"],"pattern":[{"regexp":"^\\s*\\bFile\\b\\s*\"(.*)\",\\s*\\blines?\\b\\s*(\\d+)(?:-(\\d+))?(?:,\\s*\\bcharacters\\b\\s*(\\d+)-(\\d+)\\s*)?:\\s*$","file":1,"line":2,"endLine":3,"column":4,"endColumn":5},{"regexp":"^(?:\\s*\\bParse\\b\\s*)?\\s*\\b([Ee]rror|Warning)\\b\\s*(?:(?:\\(\\s*\\bwarning\\b\\s*)?(\\d+)\\)?)?\\s*:\\s*(.*)$","severity":1,"code":2,"message":3}]}],"snippets":[{"language":"dune","path":"./snippets/dune.json"},{"language":"dune-project","path":"./snippets/dune-project.json"},{"language":"ocaml","path":"./snippets/ocaml.json"},{"language":"ocaml.ocamllex","path":"./snippets/ocamllex.json"}]},"packageManager":"yarn@4.6.0","engines":{"vscode":"^1.86.0"},"icon":"assets/logo.png","galleryBanner":{"color":"#f29100","theme":"light"}};

const { registerFileUrl, whenReady } = registerExtension(manifest, undefined, {"system":true,"readmePath":"readme.md"});


registerFileUrl('assets/logo.png', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/logo.png', import.meta.url).href, {"mimeType":"image/png","size":5902});

registerFileUrl('languages/META.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/META2.json', import.meta.url).href, {"mimeType":"application/json","size":196});

registerFileUrl('languages/dune.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/dune2.json', import.meta.url).href, {"mimeType":"application/json","size":504});

registerFileUrl('languages/menhir.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/menhir2.json', import.meta.url).href, {"mimeType":"application/json","size":366});

registerFileUrl('languages/oasis.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/oasis2.json', import.meta.url).href, {"mimeType":"application/json","size":125});

registerFileUrl('languages/ocaml.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/ocaml2.json', import.meta.url).href, {"mimeType":"application/json","size":1386});

registerFileUrl('languages/ocamlbuild.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/ocamlbuild2.json', import.meta.url).href, {"mimeType":"application/json","size":290});

registerFileUrl('languages/ocamlformat.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/ocamlformat2.json', import.meta.url).href, {"mimeType":"application/json","size":47});

registerFileUrl('languages/ocamllex.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/ocamllex2.json', import.meta.url).href, {"mimeType":"application/json","size":269});

registerFileUrl('languages/opam-install.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/opam-install2.json', import.meta.url).href, {"mimeType":"application/json","size":211});

registerFileUrl('languages/opam.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/opam2.json', import.meta.url).href, {"mimeType":"application/json","size":343});

registerFileUrl('languages/reason.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/reason2.json', import.meta.url).href, {"mimeType":"application/json","size":495});

registerFileUrl('package.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/package.json', import.meta.url).href, {"mimeType":"application/json","size":38180});

registerFileUrl('readme.md', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/readme.md', import.meta.url).href, {"mimeType":"text/markdown","size":21666});

registerFileUrl('snippets/dune-project.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/dune-project2.json', import.meta.url).href, {"mimeType":"application/json","size":577});

registerFileUrl('snippets/dune.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/dune3.json', import.meta.url).href, {"mimeType":"application/json","size":859});

registerFileUrl('snippets/ocaml.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/ocaml3.json', import.meta.url).href, {"mimeType":"application/json","size":1165});

registerFileUrl('snippets/ocamllex.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/ocamllex3.json', import.meta.url).href, {"mimeType":"application/json","size":92});

registerFileUrl('syntaxes/META.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/META.json', import.meta.url).href, {"mimeType":"application/json","size":1798});

registerFileUrl('syntaxes/atd.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/atd.json', import.meta.url).href, {"mimeType":"application/json","size":1653});

registerFileUrl('syntaxes/cram.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/cram.json', import.meta.url).href, {"mimeType":"application/json","size":4251});

registerFileUrl('syntaxes/dune-project.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/dune-project.json', import.meta.url).href, {"mimeType":"application/json","size":13986});

registerFileUrl('syntaxes/dune-workspace.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/dune-workspace.json', import.meta.url).href, {"mimeType":"application/json","size":10771});

registerFileUrl('syntaxes/dune.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/dune.json', import.meta.url).href, {"mimeType":"application/json","size":80328});

registerFileUrl('syntaxes/menhir-action.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/menhir-action.json', import.meta.url).href, {"mimeType":"application/json","size":809});

registerFileUrl('syntaxes/menhir.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/menhir.json', import.meta.url).href, {"mimeType":"application/json","size":11208});

registerFileUrl('syntaxes/merlin.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/merlin.json', import.meta.url).href, {"mimeType":"application/json","size":1778});

registerFileUrl('syntaxes/oasis.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/oasis.json', import.meta.url).href, {"mimeType":"application/json","size":1764});

registerFileUrl('syntaxes/ocaml-markdown-codeblock.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/ocaml-markdown-codeblock.json', import.meta.url).href, {"mimeType":"application/json","size":1084});

registerFileUrl('syntaxes/ocaml.interface.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/ocaml.interface.json', import.meta.url).href, {"mimeType":"application/json","size":6643});

registerFileUrl('syntaxes/ocaml.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/ocaml.json', import.meta.url).href, {"mimeType":"application/json","size":21800});

registerFileUrl('syntaxes/ocamlbuild.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/ocamlbuild.json', import.meta.url).href, {"mimeType":"application/json","size":3069});

registerFileUrl('syntaxes/ocamldoc.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/ocamldoc.json', import.meta.url).href, {"mimeType":"application/json","size":10389});

registerFileUrl('syntaxes/ocamlformat.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/ocamlformat.json', import.meta.url).href, {"mimeType":"application/json","size":8756});

registerFileUrl('syntaxes/ocamllex.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/ocamllex.json', import.meta.url).href, {"mimeType":"application/json","size":2479});

registerFileUrl('syntaxes/opam-install.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/opam-install.json', import.meta.url).href, {"mimeType":"application/json","size":589});

registerFileUrl('syntaxes/opam.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/opam.json', import.meta.url).href, {"mimeType":"application/json","size":2926});

registerFileUrl('syntaxes/reason-markdown-codeblock.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/reason-markdown-codeblock.json', import.meta.url).href, {"mimeType":"application/json","size":1099});

registerFileUrl('syntaxes/reason.json', new URL('../assets/ocamllabs.ocaml-platform-1.28.0.vsix/reason.json', import.meta.url).href, {"mimeType":"application/json","size":85284});

export { whenReady };
